@@ -1,10 +1,10 @@
-from typing import List, Dict, Any
+from typing import Any
 
 from bolinette import blnt, core
 from bolinette.blnt.objects import Pagination, PaginationParams, OrderByParams
 from bolinette.blnt.database.queries import BaseQuery, RelationalQueryBuilder, CollectionQueryBuilder
 from bolinette.exceptions import ParamConflictError, APIErrors, ParamNonNullableError
-from bolinette.utils.functions import setattr_, getattr_
+from bolinette.utils.functions import setattr_, getattr_, async_invoke
 
 
 class Repository:
@@ -27,7 +27,7 @@ class Repository:
     def query(self):
         return self._query_builder.query()
 
-    async def get_all(self, pagination: PaginationParams = None, order_by: List[OrderByParams] = None):
+    async def get_all(self, pagination: PaginationParams = None, order_by: list[OrderByParams] = None):
         if order_by is None:
             order_by = []
         query = self.query()
@@ -47,20 +47,24 @@ class Repository:
     async def get_first_by(self, key: str, value):
         return await self.query().filter_by(**{key: value}).first()
 
-    async def create(self, values: Dict[str, Any]):
-        filtered = await self._validate_model(values)
+    async def create(self, values: dict[str, Any], **kwargs):
+        await self._call_mixin_methods('create', self, values=values, **kwargs)
+        filtered = await self._validate_model(values, kwargs)
         entity = await self._query_builder.insert_entity(filtered)
         return entity
 
-    async def update(self, entity, values: Dict[str, Any]):
+    async def update(self, entity, values: dict[str, Any], **kwargs):
+        await self._call_mixin_methods('update', self, entity=entity, values=values, **kwargs)
         await self._map_model(entity, values)
         return await self._query_builder.update_entity(entity)
 
-    async def patch(self, entity, values: Dict[str, Any]):
+    async def patch(self, entity, values: dict[str, Any], **kwargs):
+        await self._call_mixin_methods('patch', self, entity=entity, values=values, **kwargs)
         await self._map_model(entity, values, patch=True)
         return await self._query_builder.update_entity(entity)
 
-    async def delete(self, entity):
+    async def delete(self, entity, **kwargs):
+        await self._call_mixin_methods('delete', self, entity=entity, **kwargs)
         return await self._query_builder.delete_entity(entity)
 
     @staticmethod
@@ -71,14 +75,11 @@ class Repository:
         items = await query.offset(page * per_page).limit(per_page).all()
         return Pagination(items, page, per_page, total)
 
-    async def _validate_model(self, values: Dict[str, Any]):
+    async def _validate_model(self, values: dict[str, Any], repo_args: dict[str, Any]):
         api_errors = APIErrors()
-        ignore_keys = []
+        ignore_keys: list[str] = []
         for _, relationship in self.model.__props__.get_relationships():
-            key = relationship.name
-            if key in values and values[key] is not None:
-                if relationship.foreign_key is not None:
-                    ignore_keys.append(relationship.foreign_key.name)
+            await self._validate_linked_model(relationship, values, repo_args, ignore_keys)
         for _, column in self.model.__props__.get_columns():
             key = column.name
             if column.auto_increment or key in ignore_keys:
@@ -96,7 +97,21 @@ class Repository:
             raise api_errors
         return values
 
-    async def _map_model(self, entity, values: Dict[str, Any], patch=False):
+    async def _validate_linked_model(self, relationship: 'core.models.Relationship', values: dict[str, Any],
+                                     repo_args: dict[str, Any], ignore_keys: list[str]):
+        if relationship.foreign_key is None:
+            return
+        foreign_key = relationship.foreign_key.name
+        if values.get(foreign_key) is not None:
+            return
+        key = relationship.name
+        if key in values:
+            ignore_keys.append(foreign_key)
+            linked = values[key]
+            if isinstance(linked, dict):
+                values[key] = await relationship.target_model.__repo__.create(values[key], **repo_args)
+
+    async def _map_model(self, entity, values: dict[str, Any], patch=False):
         api_errors = APIErrors()
         for _, column in self.model.__props__.get_columns():
             key = column.name
@@ -114,3 +129,8 @@ class Repository:
             setattr_(entity, key, new)
         if api_errors:
             raise api_errors
+
+    async def _call_mixin_methods(self, method_name: str, *args, **kwargs):
+        for _, mixin in self.model.__props__.mixins.items():
+            if method_name in mixin:
+                await async_invoke(mixin[method_name].func, *args, **kwargs)
