@@ -1,17 +1,17 @@
 from typing import Type, TypeVar, Generic
 
-T = TypeVar('T')
+_T = TypeVar('_T')
 
 
-class InitProxy(Generic[T]):
-    def __init__(self, proxy_cls: Type[T], **kwargs):
+class InitProxy(Generic[_T]):
+    def __init__(self, proxy_cls: Type[_T], **kwargs):
         self._proxy_cls = proxy_cls
         self._kwargs = kwargs
 
-    def instantiate(self, **kwargs) -> T:
+    def instantiate(self, **kwargs) -> _T:
         return self._proxy_cls(**(self._kwargs | kwargs))
 
-    def of_type(self, proxy_cls: Type[T]) -> bool:
+    def of_type(self, proxy_cls: Type[_T]) -> bool:
         return self._proxy_cls == proxy_cls
 
     def __repr__(self):
