@@ -1,7 +1,5 @@
 from bolinette.web.method import HttpMethod
-from bolinette.web.controller import (
-    Controller, ControllerMetadata, ControllerRoute, Expects, Returns, MiddlewareTrack
-)
+from bolinette.web.controller import Controller, ControllerMetadata, ControllerRoute, Expects, Returns
 from bolinette.web.middleware import Middleware, MiddlewareMetadata, InternalMiddleware
 from bolinette.web.topic import Topic, TopicMetadata, TopicChannel
 from bolinette.web.resources import BolinetteResources, BolinetteResource
